@@ -1,16 +1,17 @@
 //! Error types and error handling utilities.
 
-use std::convert::Infallible;
+use std::{borrow::Cow, convert::Infallible};
+
+/// The result with error type defaults to [Error].
+pub type Result<T, E = Error> = std::result::Result<T, E>;
 
 /// The error type for this crate.
 #[derive(Debug, thiserror::Error)]
 pub enum Error {
-    #[error("checksum mismatch error: expect {expect:}, but found {found:}")]
-    ChecksumMismatchError { expect: String, found: String },
-    #[error("unexpected EOF")]
-    UnexpectedEofError,
-    #[error("unicode error: {desc:}")]
-    UnicodeError { desc: String },
+    #[error("checksum mismatch error: expect {expect:#010x}, but found {found:#010x}")]
+    ChecksumMismatch { expect: u32, found: u32 },
+    #[error("unexpected end of file")]
+    UnexpectedEof,
     #[error("errored to decode example: {0}")]
     ExampleDecodeError(prost::DecodeError),
     #[error("errored to encode example: {0}")]
@@ -18,14 +19,25 @@ pub enum Error {
     #[error("I/O error: {0}")]
     IoError(std::io::Error),
     #[error("conversion error: {desc:}")]
-    ConversionError { desc: String },
+    ConversionError { desc: Cow<'static, str> },
     #[error("invalid arguments: {desc:}")]
-    InvalidArgumentsError { desc: String },
+    InvalidArgumentsError { desc: Cow<'static, str> },
     #[cfg(feature = "with-tch")]
     #[error("tch error: {0}")]
     TchError(tch::TchError),
 }
 
+impl Error {
+    #[allow(dead_code)]
+    pub(crate) fn conversion(desc: impl Into<Cow<'static, str>>) -> Self {
+        Self::ConversionError { desc: desc.into() }
+    }
+
+    pub(crate) fn invalid_argument(desc: impl Into<Cow<'static, str>>) -> Self {
+        Self::ConversionError { desc: desc.into() }
+    }
+}
+
 impl From<std::io::Error> for Error {
     fn from(error: std::io::Error) -> Self {
         Self::IoError(error)
@@ -56,3 +68,12 @@ impl From<tch::TchError> for Error {
         Self::TchError(error)
     }
 }
+
+macro_rules! ensure_argument {
+    ($cond:expr, $($arg:tt) *) => {
+        if !$cond {
+            return Err(crate::error::Error::invalid_argument(format!( $($arg)* )));
+        }
+    };
+}
+pub(crate) use ensure_argument;
